@@ -11,6 +11,7 @@ from flexlate.exc import (
     InvalidTemplateTypeException,
     FlexlateProjectConfigFileNotExistsException,
 )
+from flexlate.finder.multi import MultiFinder
 from flexlate.finder.specific.base import TemplateFinder
 from flexlate.finder.specific.cookiecutter import CookiecutterFinder
 from flexlate.finder.specific.copier import CopierFinder
@@ -49,42 +50,21 @@ class TemplateSource(BaseModel):
             render_relative_root_in_template=template.render_relative_root_in_template,
         )
 
-    def to_template(self, version: Optional[str] = None) -> Template:
+    def to_template(
+        self, version: Optional[str] = None, finder: MultiFinder = MultiFinder()
+    ) -> Template:
         if self.type == TemplateType.BASE:
             raise InvalidTemplateTypeException(
                 "base type is not allowed for concrete templates"
             )
-        finder: TemplateFinder
-        if self.type == TemplateType.COOKIECUTTER:
-            finder = CookiecutterFinder()
-        elif self.type == TemplateType.COPIER:
-            finder = CopierFinder()
-        else:
-            raise InvalidTemplateTypeException(
-                f"no handling for template type {self.type} in creating template from source"
-            )
-        kwargs = dict(name=self.name)
-        version = version or self.version
-        if version is not None:
-            kwargs.update(version=version)
+        if version is None:
+            version = self.version
+        template = finder.find(
+            self.git_url or str(self.absolute_local_path), version=version
+        )
+        template.name = self.name
         # TODO: Can we remove target_version from templates?
-        if self.target_version is not None:
-            kwargs.update(target_version=self.target_version)
-        if self.git_url is not None:
-            kwargs.update(git_url=self.git_url)
-        local_path: Path
-        if self.git_url is not None:
-            # TODO: Avoid unnecessary git repo cloning
-            #  We already know that we have it by this point, but need to get the local path
-            #  and the logic to resolve the version that may be None is entertwined with the
-            #  cloning and local path determination
-            local_path, _ = get_local_repo_path_and_name_cloning_if_repo_url(
-                self.git_url, version=version
-            )
-        else:
-            local_path = self.absolute_local_path
-
-        template = finder.find(self.git_url or str(local_path), local_path, **kwargs)
+        template.target_version = self.target_version
         # Keep original template source path (may be relative), so that later when
         # updating templates, it can update the path without forcing it to be absolute
         template.template_source_path = self.path
@@ -248,6 +228,11 @@ def _load_nested_configs(
         configs.append(config)
     for folder_or_file in root.iterdir():
         if folder_or_file.is_dir():
+            # Check to see if this is a nested flexlate project. If so, don't load the config,
+            # instead that config should be associated with the nested project.
+            if (folder_or_file / "flexlate-project.json").exists():
+                continue
+
             configs.extend(
                 _load_nested_configs(
                     folder_or_file,
